@@ -3,34 +3,30 @@ use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '1.69';
+our $VERSION = '1.70';
 
 use Data::Dumper;
 
 BEGIN {
 
-    # we need to do some trickery for DTS due to a circular install
+    # we need to do some trickery for Devel::Trace::Subs due to circular
+    # referencing, which broke CPAN installs. DTS does nothing if not presented,
+    # per this code
 
     eval {
         require Devel::Trace::Subs;
-    };
-
-    eval {
         import Devel::Trace::Subs qw(trace);
     };
 
     if (! defined &trace){
         *trace = sub {};
     }
-};
+}
 
 sub new {
-    
     trace() if $ENV{TRACE};
 
-    my $class = shift;
-    my $data = shift;
-    my $name = shift;
+    my ($class, $data, $name) = @_;
 
     my $self = bless {}, $class;
 
@@ -40,38 +36,25 @@ sub new {
     return $self;
 }
 sub name {
-    
     trace() if $ENV{TRACE};
-    
-    my $self = shift;
-    return $self->{data}{name};
+    return $_[0]->{data}{name};
 }
 sub start {
-    
     trace() if $ENV{TRACE};
-    
-    my $self = shift;
-    return $self->{data}{start};
+    return $_[0]->{data}{start};
 }
 sub end {
-    
     trace() if $ENV{TRACE};
-    
-    my $self = shift;
-    return $self->{data}{end};
+    return $_[0]->{data}{end};
 }
 sub line_count {
-    
     trace() if $ENV{TRACE};
-    
-    my $self = shift;
-    return $self->{data}{num_lines};
+    return $_[0]->{data}{num_lines};
 }
 sub lines {
-    
     trace() if $ENV{TRACE};
 
-    my $self = shift;
+    my ($self) = @_;
 
     my @line_linenum;
 
@@ -88,13 +71,8 @@ sub lines {
     return \@line_linenum;
 }
 sub code {
-    
     trace() if $ENV{TRACE};
-
-    my $self = shift;
-
-    my $code = $self->{data}{code};
-
-    return $code;
+    return $_[0]->{data}{code};
 }
+
 1;
